"""
Usage:
    pulses [--gpio <gpio>] [--initial <initialMethod>] [--loop <loopMethod>]
                           [--final <finalMethod>] [--delay <delayMethod>]
                           [--min <min>] [--max <max>] [--delay-val <delay>]
                           [--verbose]

Options:
    -g --gpio=<gpio>         GPIO to use [default: 12]
    -i --initial=<method>    Initial method
    -l --loop=<method>       Loop method [default: sin]
    -f --final=<method>      Final method
    -d --delay=<method>      Delay method [default: constant]

    -m --min=<min>           Minimum value [default: 2]
    -M --max=<max>           Maximum value [default: 50]
    -D --delay-val=<delay>   Base delay value [default: 0.01]

    -V --verbose             Verbose mode [default: True]

    -h --help                Show help.
    -v --version             Show version.

""" # NOQA

import sys
import time
import logging
import signal
from docopt import docopt
from pulses import VERSION, ledPulse

logging.basicConfig(format="%(name)s %(msg)s", stream=sys.stdout)


def signal_handler(sig, frame):
    print('bailing out...')
    sys.exit(0)


def main():
    args = docopt(__doc__, version=f'pulses {VERSION}')
    signal.signal(signal.SIGINT, signal_handler)

    log = logging.getLogger()
    log.setLevel('WARNING')
    if args.get('--verbose'):
        log.setLevel('DEBUG')
        log.info('setting verbose mode')

    params = {}
    for method in ['initial', 'loop', 'final', 'delay']:
        params[f"{method}Method"] = args.get(f"--{method}")

    params['min'] = int(args.get('--min'))
    params['max'] = int(args.get('--max'))
    params['delay'] = float(args.get('--delay-val'))

    print("-" * 20)
    print("pulses CLI test tool")
    print("-" * 20)
    print("\n> loop parameters")
    for param, value in params.items():
        print(f"  {param}: {value}")
    led = ledPulse(int(args.get('--gpio')))
    led.set(**params)
    print('\nstarting loop, press Ctrl-C to stop...')
    led.start()
    while True:
        time.sleep(4)


if __name__ == "__main__":
    main()
